@@ -8,7 +8,7 @@ import sys
 from mcomix import tools
 
 APPNAME = 'MComix'
-VERSION = '3.1.0'
+VERSION = '3.1.1'
 
 HOME_DIR = tools.get_home_directory()
 CONFIG_DIR = tools.get_config_directory()
@@ -100,8 +100,8 @@ LHA_FORMATS = (
         ('application/x-lzh', 'application/x-lha', 'application/x-lzh-compressed'),
         ('lha', 'lzh'))
 PDF_FORMATS = (
-        ('application/pdf',),
-        ('pdf',))
+        ('application/pdf', 'application/x-cbp'),
+        ('pdf', 'cbp'))
 MOBI_FORMATS = (
         ('application/vnd.amazon.mobi8-ebook',),
         ('azw3',))
