@@ -76,7 +76,7 @@ class _BookArea(Gtk.ScrolledWindow):
         self._iconview.modify_base(Gtk.StateType.NORMAL, image_tools.GTK_GDK_COLOR_BLACK)
         self._iconview.enable_model_drag_source(
             Gdk.ModifierType.BUTTON1_MASK,
-            [Gtk.TargetEntry.new('book', Gtk.TargetFlags.SAME_APP,
+            [Gtk.TargetEntry.new('text/plain', Gtk.TargetFlags.SAME_APP,
                                  constants.LIBRARY_DRAG_EXTERNAL_ID)],
             Gdk.DragAction.MOVE)
         self._iconview.drag_dest_set(
@@ -236,7 +236,7 @@ class _BookArea(Gtk.ScrolledWindow):
         self.add_books(books)
 
         # Re-attach model here
-        self._iconview.set_model(self._liststore)
+        GLib.idle_add(self._iconview.set_model, self._liststore)
 
     def stop_update(self):
         """Signal that the updating of book covers should stop."""
@@ -378,6 +378,11 @@ class _BookArea(Gtk.ScrolledWindow):
             cell.set_fixed_size(width, height)
             cell.set_alignment(0.5, 0.5)
 
+    def load_covers(self):
+        self._cache.invalidate_all()
+        collection = self._library.collection_area.get_current_collection()
+        GLib.idle_add(self.display_covers, collection)
+
     def _book_size_changed(self, old, current):
         """ Called when library cover size changes. """
         old_size = prefs['library cover size']
@@ -420,9 +425,7 @@ class _BookArea(Gtk.ScrolledWindow):
                 prefs['library cover size'] = size
 
         if prefs['library cover size'] != old_size:
-            self._cache.invalidate_all()
-            collection = self._library.collection_area.get_current_collection()
-            GLib.idle_add(self.display_covers, collection)
+            self.load_covers()
 
     def _pixbuf_size(self, border_size=_BORDER_SIZE):
         # Don't forget the extra pixels for the border!
@@ -443,9 +446,11 @@ class _BookArea(Gtk.ScrolledWindow):
             except:
                 pixbuf = image_tools.MISSING_IMAGE_ICON
             pixbuf = image_tools.fit_in_rectangle(pixbuf, width, height, scale_up=True)
-            pixbuf = image_tools.add_border(pixbuf, 1, 0xFFFFFFFF)
             self._cache.add(book.path, pixbuf)
 
+        pixbuf = self._library._window.enhancer.enhance(pixbuf);
+        pixbuf = image_tools.add_border(pixbuf, 1, 0xFFFFFFFF)
+
         # Display indicator of having finished reading the book.
         # This information isn't cached in the pixbuf cache, as it changes frequently.
 
@@ -657,7 +662,7 @@ class _BookArea(Gtk.ScrolledWindow):
         num_books = len(iconview.get_selected_items())
         book = self.get_book_at_path(icon_path)
 
-        cover = self._library.backend.get_book_cover(book)
+        cover: GdkPixbuf.Pixbuf = self._library.backend.get_book_cover(book)
         if cover is None:
             cover = image_tools.MISSING_IMAGE_ICON
 
@@ -696,13 +701,14 @@ class _BookArea(Gtk.ScrolledWindow):
 
         Gtk.drag_set_icon_pixbuf(context, pointer, -5, -5)
 
-    def _drag_data_get(self, iconview, context, selection, *args):
+    def _drag_data_get(self, iconview: thumbnail_view.ThumbnailIconView, context: Gdk.DragContext,
+                       selection: Gtk.SelectionData, info: int, time: int) -> None:
         """Fill the SelectionData with (iconview) paths for the dragged books
         formatted as a string with each path separated by a comma.
         """
         paths = iconview.get_selected_items()
-        text = ','.join([str(path[0]) for path in paths])
-        selection.set('text/plain', 8, text)
+        text = ','.join(path.to_string() for path in paths)
+        selection.set_text(text, len(text))
 
     def _drag_data_received(self, widget, context, x, y, data, *args):
         """Handle drag-n-drop events ending on the book area (i.e. from
